from setuptools import setup, find_packages

setup(
    name='straightemail',
    version='0.0.4',
    author="Shreejeet Sahay",
    packages=find_packages(),
    description="straightemail is a package built with a motive to ease the email functionality as much as possible.",
    install_requires=[
    ],
    long_description = open('README.md').read(),
    long_description_content_type='text/markdown',
    py_modules=["send_email"]
    )
